pub enum Algorithm {
Ahash,
Blake3,
Foldhash,
Fxhash,
SHA256,
SHA512,
}Expand description
Enum representing supported hash algorithms.
Implements Display to allow serializing the enum variant names in PascalCase,
and ValueEnum for use with clap.
Variants
Implementations
Sourceimpl Algorithm
impl Algorithm
Sourcepub fn calculate_hash(&self, file: File) -> FIFResult<String>
pub fn calculate_hash(&self, file: File) -> FIFResult<String>
Calculate hash from a File (uses a BufReader and Heap buffer).
Sourcepub fn hash_reader<R: Read>(&self, reader: R) -> FIFResult<String>
pub fn hash_reader<R: Read>(&self, reader: R) -> FIFResult<String>
Generic hashing logic for any type implementing Read. This is used by both the main application and the test suite.